@@ -30,7 +30,7 @@ var (
 	UART0 = UART{
 		Buffer:          NewRingBuffer(),
 		Bus:             stm32.USART2,
-		AltFuncSelector: stm32.AF7_USART1_2_3,
+		AltFuncSelector: AF7_USART1_2_3,
 	}
 	UART1 = &UART0
 )
@@ -62,7 +62,19 @@ const (
 var (
 	SPI0 = SPI{
 		Bus:             stm32.SPI1,
-		AltFuncSelector: stm32.AF5_SPI1_SPI2,
+		AltFuncSelector: AF5_SPI1_SPI2,
 	}
 	SPI1 = &SPI0
 )
+
+const (
+	I2C0_SCL_PIN = PB6
+	I2C0_SDA_PIN = PB9
+)
+
+var (
+	I2C0 = I2C{
+		Bus:             stm32.I2C1,
+		AltFuncSelector: AF4_I2C1_2_3,
+	}
+)
